==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/94/94be3b7c00879f331a642276bd8cad16.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/js/libraries/froala/languages/it.js */
class __TwigTemplate_730fa44fca2335ae83885eced73a664f extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "/*!
 * froala_editor v2.4.2 (https://www.froala.com/wysiwyg-editor)
 * License https://froala.com/wysiwyg-editor/terms/
 * Copyright 2014-2017 Froala Labs
 */

/**
 * Italian
 */

\$.FE.LANGUAGE['it'] = {
  translation: {
    // Place holder
    \"Type something\": \"Digita qualcosa\",

    // Basic formatting
    \"Bold\": \"Grassetto\",
    \"Italic\": \"Corsivo\",
    \"Underline\": \"Sottolineato\",
    \"Strikethrough\": \"Barrato\",

    // Main buttons
    \"Insert\": \"Inserisci\",
    \"Delete\": \"Cancella\",
    \"Cancel\": \"Cancella\",
    \"OK\": \"Ok\",
    \"Back\": \"Indietro\",
    \"Remove\": \"Rimuovi\",
    \"More\": \"Di pi\\u00f9\",
    \"Update\": \"Aggiornare\",
    \"Style\": \"Stile\",

    // Font
    \"Font Family\": \"Carattere\",
    \"Font Size\": \"Dimensione Carattere\",

    // Colors
    \"Colors\": \"Colori\",
    \"Background\": \"Sfondo\",
    \"Text\": \"Testo\",

    // Paragraphs
    \"Paragraph Format\": \"Formattazione\",
    \"Normal\": \"Normale\",
    \"Code\": \"Codice\",
    \"Heading 1\": \"Intestazione 1\",
    \"Heading 2\": \"Intestazione 2\",
    \"Heading 3\": \"Intestazione 3\",
    \"Heading 4\": \"Intestazione 4\",

    // Style
    \"Paragraph Style\": \"Stile di paragrafo\",
    \"Inline Style\": \"Stile in fila\",

    // Alignment
    \"Align\": \"Allinea\",
    \"Align Left\": \"Allinea a Sinistra\",
    \"Align Center\": \"Allinea al Cento\",
    \"Align Right\": \"Allinea a Destra\",
    \"Align Justify\": \"Giustifica\",
    \"None\": \"Nessuno\",

    // Lists
    \"Ordered List\": \"Elenchi ordinato\",
    \"Unordered List\": \"Elenchi non ordinata\",

    // Indent
    \"Decrease Indent\": \"Riduci Rientro\",
    \"Increase Indent\": \"Aumenta Rientro\",

    // Links
    \"Insert Link\": \"Inserisci Link\",
    \"Open in new tab\": \"Apri in nuova scheda\",
    \"Open Link\": \"Link aperto\",
    \"Edit Link\": \"Modifica link\",
    \"Unlink\": \"Rimuovi link\",
    \"Choose Link\": \"Scegli link\",

    // Images
    \"Insert Image\": \"Inserisci immagine\",
    \"Upload Image\": \"Carica immagine\",
    \"By URL\": \"Per URL\",
    \"Browse\": \"Sfogliare\",
    \"Drop image\": \"Rilascia Immagine\",
    \"or click\": \"oppure fai click su\",
    \"Manage Images\": \"Gestione immagini\",
    \"Loading\": \"Caricamento\",
    \"Deleting\": \"Eliminazione\",
    \"Tags\": \"Etichetta\",
    \"Are you sure? Image will be deleted.\": \"Sei sicuro? Immagine verr\\u00e0 cancellata.\",
    \"Replace\": \"Sostituisci\",
    \"Uploading\": \"Caricamento\",
    \"Loading image\": \"Caricamento immagine\",
    \"Display\": \"Visualizzazione\",
    \"Inline\": \"In fila\",
    \"Break Text\": \"Testo di separazione\",
    \"Alternate Text\": \"Testo alternativo\",
    \"Change Size\": \"Cambio formato\",
    \"Width\": \"Larghezza\",
    \"Height\": \"Altezza\",
    \"Something went wrong. Please try again.\": \"Qualcosa \\u00e8 andato storto. Riprova, per favore.\",

    // Video
    \"Insert Video\": \"Inserisci Video\",
    \"Embedded Code\": \"Codice incorporato\",

    // Tables
    \"Insert Table\": \"Inserisci Tabella\",
    \"Table Header\": \"Intestazione della tabella\",
    \"Remove Table\": \"Rimuovere tavolo\",
    \"Table Style\": \"Stile di tabella\",
    \"Horizontal Align\": \"Allineamento orizzontale\",
    \"Row\": \"Riga\",
    \"Insert row above\": \"Inserisci una Riga Prima\",
    \"Insert row below\": \"Inserisci una Riga Dopo\",
    \"Delete row\": \"Cancella Riga\",
    \"Column\": \"Colonna\",
    \"Insert column before\": \"Inserisci una Colonna Prima\",
    \"Insert column after\": \"Inserisci una Colonna Dopo\",
    \"Delete column\": \"Cancella Colonna\",
    \"Cell\": \"Cella\",
    \"Merge cells\": \"Unisci Cella\",
    \"Horizontal split\": \"Divisione Orizzontale\",
    \"Vertical split\": \"Divisione Verticale\",
    \"Cell Background\": \"Sfondo della cella\",
    \"Vertical Align\": \"Allineamento verticale\",
    \"Top\": \"Alto\",
    \"Middle\": \"Mezzo\",
    \"Bottom\": \"Fondo\",
    \"Align Top\": \"Allinea in alto\",
    \"Align Middle\": \"Allinea al centro\",
    \"Align Bottom\": \"Allinea in basso\",
    \"Cell Style\": \"Stile di cella\",

    // Files
    \"Upload File\": \"Carica File\",
    \"Drop file\": \"Rilascia File\",

    // Emoticons
    \"Emoticons\": \"Emoticon\",
    \"Grinning face\": \"Sorridendo volto\",
    \"Grinning face with smiling eyes\": \"Sorridendo faccia con gli occhi sorridenti\",
    \"Face with tears of joy\": \"Faccia con lacrime di gioia\",
    \"Smiling face with open mouth\": \"Volto sorridente con la bocca aperta\",
    \"Smiling face with open mouth and smiling eyes\": \"Volto sorridente con la bocca aperta e gli occhi sorridenti\",
    \"Smiling face with open mouth and cold sweat\": \"Volto sorridente con la bocca aperta e sudore freddo\",
    \"Smiling face with open mouth and tightly-closed eyes\": \"Volto sorridente con la bocca aperta e gli occhi ben chiusi\",
    \"Smiling face with halo\": \"Volto sorridente con alone\",
    \"Smiling face with horns\": \"Volto sorridente con le corna\",
    \"Winking face\": \"Fare l'occhiolino volto\",
    \"Smiling face with smiling eyes\": \"Volto sorridente con gli occhi sorridenti\",
    \"Face savoring delicious food\": \"Volto assaporando cibo delizioso\",
    \"Relieved face\": \"Volto Sollevata\",
    \"Smiling face with heart-shaped eyes\": \"Volto sorridente con gli occhi a forma di cuore\",
    \"Smiling face with sunglasses\": \"Volto sorridente con gli occhiali da sole\",
    \"Smirking face\": \"Compiaciuto affrontare\",
    \"Neutral face\": \"Volto Neutral\",
    \"Expressionless face\": \"Volto inespressivo\",
    \"Unamused face\": \"Faccia non divertito\",
    \"Face with cold sweat\": \"Faccia con sudore freddo\",
    \"Pensive face\": \"Volto pensieroso\",
    \"Confused face\": \"Volto confuso\",
    \"Confounded face\": \"Volto confusi\",
    \"Kissing face\": \"Baciare faccia\",
    \"Face throwing a kiss\": \"Volto lanciando un bacio\",
    \"Kissing face with smiling eyes\": \"Baciare faccia con gli occhi sorridenti\",
    \"Kissing face with closed eyes\": \"Baciare faccia con gli occhi chiusi\",
    \"Face with stuck out tongue\": \"Faccia con la lingua fuori bloccato\",
    \"Face with stuck out tongue and winking eye\": \"Faccia con la lingua fuori bloccato e ammiccante occhio\",
    \"Face with stuck out tongue and tightly-closed eyes\": \"Faccia con la lingua fuori bloccato e gli occhi ben chiusi\",
    \"Disappointed face\": \"Volto deluso\",
    \"Worried face\": \"Faccia preoccupata\",
    \"Angry face\": \"Faccia arrabbiata\",
    \"Pouting face\": \"Fare il muso volto\",
    \"Crying face\": \"Piangere volto\",
    \"Persevering face\": \"Perseverando volto\",
    \"Face with look of triumph\": \"Affrontare con sguardo di trionfo\",
    \"Disappointed but relieved face\": \"Siamo rimasti delusi ma sollevato la faccia\",
    \"Frowning face with open mouth\": \"Accigliandosi volto con la bocca aperta\",
    \"Anguished face\": \"Volto Angosciato\",
    \"Fearful face\": \"Volto Temendo\",
    \"Weary face\": \"Volto stanco\",
    \"Sleepy face\": \"Faccia assonnata\",
    \"Tired face\": \"Volto stanco\",
    \"Grimacing face\": \"Smorfie volto\",
    \"Loudly crying face\": \"Ad alta voce che grida volto\",
    \"Face with open mouth\": \"Volto con la bocca aperta\",
    \"Hushed face\": \"Faccia ovattata\",
    \"Face with open mouth and cold sweat\": \"Volto con la bocca aperta e sudore freddo\",
    \"Face screaming in fear\": \"Volto urlando nella paura\",
    \"Astonished face\": \"Volto Stupito\",
    \"Flushed face\": \"Viso rosso\",
    \"Sleeping face\": \"Viso addormentato\",
    \"Dizzy face\": \"Faccia vertigini\",
    \"Face without mouth\": \"Volto senza bocca\",
    \"Face with medical mask\": \"Volto con la mascherina medica\",

    // Line breaker
    \"Break\": \"Separazione\",

    // Math
    \"Subscript\": \"Pedice\",
    \"Superscript\": \"Apice\",

    // Full screen
    \"Fullscreen\": \"Schermo intero\",

    // Horizontal line
    \"Insert Horizontal Line\": \"Inserisci Divisore Orizzontale\",

    // Clear formatting
    \"Clear Formatting\": \"Cancella formattazione\",

    // Undo, redo
    \"Undo\": \"Annulla\",
    \"Redo\": \"Ripeti\",

    // Select all
    \"Select All\": \"Seleziona Tutto\",

    // Code view
    \"Code View\": \"Visualizzazione di codice\",

    // Quote
    \"Quote\": \"Citazione\",
    \"Increase\": \"Aumentare\",
    \"Decrease\": \"Diminuzione\",

    // Quick Insert
    \"Quick Insert\": \"Inserto rapida\"
  },
  direction: \"ltr\"
};
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/js/libraries/froala/languages/it.js";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/js/libraries/froala/languages/it.js", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/js/libraries/froala/languages/it.js");
    }
}

==> production-demo-20260214_152721.tar.gz: var/www/html/production-demo/var/tmp/twig/94/94be3b7c00879f331a642276bd8cad16.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/js/libraries/froala/languages/it.js */
class __TwigTemplate_730fa44fca2335ae83885eced73a664f extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "/*!
 * froala_editor v2.4.2 (https://www.froala.com/wysiwyg-editor)
 * License https://froala.com/wysiwyg-editor/terms/
 * Copyright 2014-2017 Froala Labs
 */

/**
 * Italian
 */

\$.FE.LANGUAGE['it'] = {
  translation: {
    // Place holder
    \"Type something\": \"Digita qualcosa\",

    // Basic formatting
    \"Bold\": \"Grassetto\",
    \"Italic\": \"Corsivo\",
    \"Underline\": \"Sottolineato\",
    \"Strikethrough\": \"Barrato\",

    // Main buttons
    \"Insert\": \"Inserisci\",
    \"Delete\": \"Cancella\",
    \"Cancel\": \"Cancella\",
    \"OK\": \"Ok\",
    \"Back\": \"Indietro\",
    \"Remove\": \"Rimuovi\",
    \"More\": \"Di pi\\u00f9\",
    \"Update\": \"Aggiornare\",
    \"Style\": \"Stile\",

    // Font
    \"Font Family\": \"Carattere\",
    \"Font Size\": \"Dimensione Carattere\",

    // Colors
    \"Colors\": \"Colori\",
    \"Background\": \"Sfondo\",
    \"Text\": \"Testo\",

    // Paragraphs
    \"Paragraph Format\": \"Formattazione\",
    \"Normal\": \"Normale\",
    \"Code\": \"Codice\",
    \"Heading 1\": \"Intestazione 1\",
    \"Heading 2\": \"Intestazione 2\",
    \"Heading 3\": \"Intestazione 3\",
    \"Heading 4\": \"Intestazione 4\",

    // Style
    \"Paragraph Style\": \"Stile di paragrafo\",
    \"Inline Style\": \"Stile in fila\",

    // Alignment
    \"Align\": \"Allinea\",
    \"Align Left\": \"Allinea a Sinistra\",
    \"Align Center\": \"Allinea al Cento\",
    \"Align Right\": \"Allinea a Destra\",
    \"Align Justify\": \"Giustifica\",
    \"None\": \"Nessuno\",

    // Lists
    \"Ordered List\": \"Elenchi ordinato\",
    \"Unordered List\": \"Elenchi non ordinata\",

    // Indent
    \"Decrease Indent\": \"Riduci Rientro\",
    \"Increase Indent\": \"Aumenta Rientro\",

    // Links
    \"Insert Link\": \"Inserisci Link\",
    \"Open in new tab\": \"Apri in nuova scheda\",
    \"Open Link\": \"Link aperto\",
    \"Edit Link\": \"Modifica link\",
    \"Unlink\": \"Rimuovi link\",
    \"Choose Link\": \"Scegli link\",

    // Images
    \"Insert Image\": \"Inserisci immagine\",
    \"Upload Image\": \"Carica immagine\",
    \"By URL\": \"Per URL\",
    \"Browse\": \"Sfogliare\",
    \"Drop image\": \"Rilascia Immagine\",
    \"or click\": \"oppure fai click su\",
    \"Manage Images\": \"Gestione immagini\",
    \"Loading\": \"Caricamento\",
    \"Deleting\": \"Eliminazione\",
    \"Tags\": \"Etichetta\",
    \"Are you sure? Image will be deleted.\": \"Sei sicuro? Immagine verr\\u00e0 cancellata.\",
    \"Replace\": \"Sostituisci\",
    \"Uploading\": \"Caricamento\",
    \"Loading image\": \"Caricamento immagine\",
    \"Display\": \"Visualizzazione\",
    \"Inline\": \"In fila\",
    \"Break Text\": \"Testo di separazione\",
    \"Alternate Text\": \"Testo alternativo\",
    \"Change Size\": \"Cambio formato\",
    \"Width\": \"Larghezza\",
    \"Height\": \"Altezza\",
    \"Something went wrong. Please try again.\": \"Qualcosa \\u00e8 andato storto. Riprova, per favore.\",

    // Video
    \"Insert Video\": \"Inserisci Video\",
    \"Embedded Code\": \"Codice incorporato\",

    // Tables
    \"Insert Table\": \"Inserisci Tabella\",
    \"Table Header\": \"Intestazione della tabella\",
    \"Remove Table\": \"Rimuovere tavolo\",
    \"Table Style\": \"Stile di tabella\",
    \"Horizontal Align\": \"Allineamento orizzontale\",
    \"Row\": \"Riga\",
    \"Insert row above\": \"Inserisci una Riga Prima\",
    \"Insert row below\": \"Inserisci una Riga Dopo\",
    \"Delete row\": \"Cancella Riga\",
    \"Column\": \"Colonna\",
    \"Insert column before\": \"Inserisci una Colonna Prima\",
    \"Insert column after\": \"Inserisci una Colonna Dopo\",
    \"Delete column\": \"Cancella Colonna\",
    \"Cell\": \"Cella\",
    \"Merge cells\": \"Unisci Cella\",
    \"Horizontal split\": \"Divisione Orizzontale\",
    \"Vertical split\": \"Divisione Verticale\",
    \"Cell Background\": \"Sfondo della cella\",
    \"Vertical Align\": \"Allineamento verticale\",
    \"Top\": \"Alto\",
    \"Middle\": \"Mezzo\",
    \"Bottom\": \"Fondo\",
    \"Align Top\": \"Allinea in alto\",
    \"Align Middle\": \"Allinea al centro\",
    \"Align Bottom\": \"Allinea in basso\",
    \"Cell Style\": \"Stile di cella\",

    // Files
    \"Upload File\": \"Carica File\",
    \"Drop file\": \"Rilascia File\",

    // Emoticons
    \"Emoticons\": \"Emoticon\",
    \"Grinning face\": \"Sorridendo volto\",
    \"Grinning face with smiling eyes\": \"Sorridendo faccia con gli occhi sorridenti\",
    \"Face with tears of joy\": \"Faccia con lacrime di gioia\",
    \"Smiling face with open mouth\": \"Volto sorridente con la bocca aperta\",
    \"Smiling face with open mouth and smiling eyes\": \"Volto sorridente con la bocca aperta e gli occhi sorridenti\",
    \"Smiling face with open mouth and cold sweat\": \"Volto sorridente con la bocca aperta e sudore freddo\",
    \"Smiling face with open mouth and tightly-closed eyes\": \"Volto sorridente con la bocca aperta e gli occhi ben chiusi\",
    \"Smiling face with halo\": \"Volto sorridente con alone\",
    \"Smiling face with horns\": \"Volto sorridente con le corna\",
    \"Winking face\": \"Fare l'occhiolino volto\",
    \"Smiling face with smiling eyes\": \"Volto sorridente con gli occhi sorridenti\",
    \"Face savoring delicious food\": \"Volto assaporando cibo delizioso\",
    \"Relieved face\": \"Volto Sollevata\",
    \"Smiling face with heart-shaped eyes\": \"Volto sorridente con gli occhi a forma di cuore\",
    \"Smiling face with sunglasses\": \"Volto sorridente con gli occhiali da sole\",
    \"Smirking face\": \"Compiaciuto affrontare\",
    \"Neutral face\": \"Volto Neutral\",
    \"Expressionless face\": \"Volto inespressivo\",
    \"Unamused face\": \"Faccia non divertito\",
    \"Face with cold sweat\": \"Faccia con sudore freddo\",
    \"Pensive face\": \"Volto pensieroso\",
    \"Confused face\": \"Volto confuso\",
    \"Confounded face\": \"Volto confusi\",
    \"Kissing face\": \"Baciare faccia\",
    \"Face throwing a kiss\": \"Volto lanciando un bacio\",
    \"Kissing face with smiling eyes\": \"Baciare faccia con gli occhi sorridenti\",
    \"Kissing face with closed eyes\": \"Baciare faccia con gli occhi chiusi\",
    \"Face with stuck out tongue\": \"Faccia con la lingua fuori bloccato\",
    \"Face with stuck out tongue and winking eye\": \"Faccia con la lingua fuori bloccato e ammiccante occhio\",
    \"Face with stuck out tongue and tightly-closed eyes\": \"Faccia con la lingua fuori bloccato e gli occhi ben chiusi\",
    \"Disappointed face\": \"Volto deluso\",
    \"Worried face\": \"Faccia preoccupata\",
    \"Angry face\": \"Faccia arrabbiata\",
    \"Pouting face\": \"Fare il muso volto\",
    \"Crying face\": \"Piangere volto\",
    \"Persevering face\": \"Perseverando volto\",
    \"Face with look of triumph\": \"Affrontare con sguardo di trionfo\",
    \"Disappointed but relieved face\": \"Siamo rimasti delusi ma sollevato la faccia\",
    \"Frowning face with open mouth\": \"Accigliandosi volto con la bocca aperta\",
    \"Anguished face\": \"Volto Angosciato\",
    \"Fearful face\": \"Volto Temendo\",
    \"Weary face\": \"Volto stanco\",
    \"Sleepy face\": \"Faccia assonnata\",
    \"Tired face\": \"Volto stanco\",
    \"Grimacing face\": \"Smorfie volto\",
    \"Loudly crying face\": \"Ad alta voce che grida volto\",
    \"Face with open mouth\": \"Volto con la bocca aperta\",
    \"Hushed face\": \"Faccia ovattata\",
    \"Face with open mouth and cold sweat\": \"Volto con la bocca aperta e sudore freddo\",
    \"Face screaming in fear\": \"Volto urlando nella paura\",
    \"Astonished face\": \"Volto Stupito\",
    \"Flushed face\": \"Viso rosso\",
    \"Sleeping face\": \"Viso addormentato\",
    \"Dizzy face\": \"Faccia vertigini\",
    \"Face without mouth\": \"Volto senza bocca\",
    \"Face with medical mask\": \"Volto con la mascherina medica\",

    // Line breaker
    \"Break\": \"Separazione\",

    // Math
    \"Subscript\": \"Pedice\",
    \"Superscript\": \"Apice\",

    // Full screen
    \"Fullscreen\": \"Schermo intero\",

    // Horizontal line
    \"Insert Horizontal Line\": \"Inserisci Divisore Orizzontale\",

    // Clear formatting
    \"Clear Formatting\": \"Cancella formattazione\",

    // Undo, redo
    \"Undo\": \"Annulla\",
    \"Redo\": \"Ripeti\",

    // Select all
    \"Select All\": \"Seleziona Tutto\",

    // Code view
    \"Code View\": \"Visualizzazione di codice\",

    // Quote
    \"Quote\": \"Citazione\",
    \"Increase\": \"Aumentare\",
    \"Decrease\": \"Diminuzione\",

    // Quick Insert
    \"Quick Insert\": \"Inserto rapida\"
  },
  direction: \"ltr\"
};
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/js/libraries/froala/languages/it.js";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/js/libraries/froala/languages/it.js", "/var/www/html/production-demo/app/bundles/CoreBundle/Assets/js/libraries/froala/languages/it.js");
    }
}
